;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: DelSigPlusINT.asm
;;   Version: 1.0, Updated on 2012/9/21 at 11:58:50
;;  Generated by PSoC Designer 5.3.2710
;;
;;  DESCRIPTION: Assembler interrupt service routine for the Delta-Sigma ADC
;;               User Module based on the Type 2 Decimator. This code works for
;;               both the first and second-order modulator topologies where
;;               the decimation rate requires no extra shift of the data
;;               in software.
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress Semiconductor 2012. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

include "m8c.inc"
include "memory.inc"
include "DelSigPlus.inc"


;-----------------------------------------------
;  Global Symbols
;-----------------------------------------------

export _DelSigPlus_ADC_ISR
export _DelSigPlus_iResult
export  DelSigPlus_iResult
export _DelSigPlus_bfStatus
export  DelSigPlus_bfStatus


;-----------------------------------------------
; Variable Allocation
;-----------------------------------------------
AREA InterruptRAM (RAM, REL, CON)

_DelSigPlus_iResult:
 DelSigPlus_iResult:               blk 2             ;ADC output value
_DelSigPlus_bfStatus:
 DelSigPlus_bfStatus:              blk 1             ;Data Valid Flag


;-----------------------------------------------
;  Private Symbols
;-----------------------------------------------
MSB:                               equ 0
LSB:                               equ 1
RES:                               equ 12
UMAX:                              equ (1<<RES) - 1  ; 2^RES - 1


;@PSoC_UserCode_INIT@ (Do not change this line.)
;---------------------------------------------------
; Insert your custom declarations below this banner
;---------------------------------------------------

;------------------------
; Includes
;------------------------

;------------------------
; Exports
;------------------------

;------------------------
; Constant Definitions
;------------------------

;------------------------
; Variable Allocation
;------------------------

;---------------------------------------------------
; Insert your custom declarations above this banner
;---------------------------------------------------
;@PSoC_UserCode_END@ (Do not change this line.)


AREA UserModules (ROM, REL, CON)

;;=============================================================================
;;  FUNCTION NAME: _DelSigPlus_ADC_ISR:
;;=============================================================================
;;
_DelSigPlus_ADC_ISR:
   push  A
   mov   A, reg[DelSigPlus_DEC_DH]
   cmp   A, >(UMAX+1)                            ; Is value >= 2^RES?
   jc    .NoOverflow                             ;    No, Data is in normal range
   mov   A, reg[DelSigPlus_DEC_DL]
   mov   [DelSigPlus_iResult+MSB], >UMAX         ;   Yes, limit to 2^RES - 1
   mov   [DelSigPlus_iResult+LSB], <UMAX         ;          as expected
   jmp   .ConversionReady

.NoOverflow:
   mov   [DelSigPlus_iResult+MSB], A
   mov   A, reg[DelSigPlus_DEC_DL]
   mov   [DelSigPlus_iResult+LSB], A

.ConversionReady:
IF DelSigPlus_2S_COMPLEMENT
   ; Internal hardware format is unsigned; optionally convert so zero is half scale
   sub   [DelSigPlus_iResult+MSB], >(UMAX+1)>>1
ENDIF
   mov [DelSigPlus_bfStatus], DelSigPlus_DATA_READY_BIT        

   ;@PSoC_UserCode_BODY@ (Do not change this line.)
   ;---------------------------------------------------
   ; Insert your custom code below this banner
   ;---------------------------------------------------
	
	PRESERVE_CPU_CONTEXT
	lcall _ADC_Ready_ISR
	RESTORE_CPU_CONTEXT

   ;---------------------------------------------------
   ; Insert your custom code above this banner
   ;---------------------------------------------------
   ;@PSoC_UserCode_END@ (Do not change this line.)

   pop A
   reti

; end of file DelSigPlusINT.asm
